@@ -18,9 +18,10 @@ import functools
 import asyncio
 
 import octobot_commons.logging as bot_logging
+import octobot_commons.singleton as singleton
 
 
-class Authenticator:
+class Authenticator(singleton.Singleton):
     """
     Abstract class to be implemented when using authenticated requests
     """
@@ -31,6 +32,9 @@ class Authenticator:
         )
         self.initialized_event: asyncio.Event = None
         self.supports: None
+        self.feed_callbacks = {}
+        # also register this instance for the base Authenticator class in singleton
+        singleton.Singleton._instances[Authenticator] = self
 
     @abc.abstractmethod
     def login(self, username, password):
@@ -73,6 +77,18 @@ class Authenticator:
         """
         raise NotImplementedError
 
+    async def register_feed_callback(self, topic, callback):
+        """
+        Registers a feed callback
+        """
+        raise NotImplementedError
+
+    async def send(self, message, channel_type, identifier=None):
+        """
+        Sends a message
+        """
+        raise NotImplementedError
+
     @abc.abstractmethod
     def is_initialized(self) -> bool:
         """
