@@ -17,6 +17,7 @@
 
 import octobot_commons
 import octobot_commons.enums as enums
+import octobot_commons.constants as constants
 import octobot_commons.logging as logging_util
 import octobot_commons.symbol_util as symbol_util
 import octobot_commons.timestamp_util as timestamp_util
@@ -137,13 +138,13 @@ def global_portfolio_pretty_print(
     :return: the global portfolio pretty printed
     """
     result = []
-    for currency, asset in global_portfolio.items():
-        if asset.total > 0:
+    for currency, asset_dict in global_portfolio.items():
+        if asset_dict[constants.PORTFOLIO_TOTAL] > 0:
             # fill lines with empty spaces if necessary
-            total = get_min_string_from_number(asset.total)
+            total = get_min_string_from_number(asset_dict[constants.PORTFOLIO_TOTAL])
             if markdown:
                 total = "{:<10}".format(total)
-            available = f"({get_min_string_from_number(asset.available)})"
+            available = f"({get_min_string_from_number(asset_dict[constants.PORTFOLIO_AVAILABLE])})"
             if markdown:
                 available = "{:<12}".format(available)
 
