@@ -14,6 +14,7 @@
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
 import pytest
+import pathlib
 import octobot_commons.profiles as profiles
 import octobot_commons.tests.test_config as test_config
 
@@ -22,6 +23,10 @@ def get_profile_path():
     return test_config.TEST_CONFIG_FOLDER
 
 
+def get_profiles_path():
+    return pathlib.Path(get_profile_path()).parent
+
+
 @pytest.fixture
 def profile():
     return profiles.Profile(get_profile_path())
